@@ -1,4 +1,4 @@
-# Copyright 2014 Gentoo Foundation
+# Copyright 2014-2017 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 doc = """Git plug-in module for portage.
@@ -16,22 +16,22 @@ class CheckGitConfig(CheckSyncConfig):
 		self.checks.append('check_depth')
 
 	def check_depth(self):
-		d = self.repo.sync_depth
-		# default
-		self.repo.sync_depth = 1
+		for attr in ('clone_depth', 'sync_depth'):
+			self._check_depth(attr)
+
+	def _check_depth(self, attr):
+		d = getattr(self.repo, attr)
 
 		if d is not None:
 			try:
 				d = int(d)
 			except ValueError:
 				writemsg_level("!!! %s\n" %
-					_("sync-depth value is not a number: '%s'")
-					% (d),
+					_("%s value is not a number: '%s'")
+					% (attr.replace('_', '-'), d),
 					level=self.logger.ERROR, noiselevel=-1)
 			else:
-				if d == 0:
-					d = None
-				self.repo.sync_depth = d
+				setattr(self.repo, attr, d)
 
 
 module_spec = {
@@ -40,18 +40,23 @@ module_spec = {
 	'provides':{
 		'git-module': {
 			'name': "git",
+			'sourcefile': "git",
 			'class': "GitSync",
 			'description': doc,
-			'functions': ['sync', 'new', 'exists'],
+			'functions': ['sync', 'new', 'exists', 'retrieve_head'],
 			'func_desc': {
 				'sync': 'Performs a git pull on the repository',
 				'new': 'Creates the new repository at the specified location',
 				'exists': 'Returns a boolean of whether the specified dir ' +
 					'exists and is a valid Git repository',
+				'retrieve_head': 'Returns the head commit hash',
 			},
 			'validate_config': CheckGitConfig,
 			'module_specific_options': (
+				'sync-git-clone-env',
 				'sync-git-clone-extra-opts',
+				'sync-git-env',
+				'sync-git-pull-env',
 				'sync-git-pull-extra-opts',
 				),
 		}
